@@ -32,11 +32,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 static RtpProfile rtp_profile;
 
-#ifdef _MSC_VER
-extern __declspec(dllimport) MSWebCamDesc mire_desc;
-#else
-extern MSWebCamDesc mire_desc;
-#endif
 
 
 
@@ -44,16 +39,29 @@ extern MSWebCamDesc mire_desc;
 #define H264_PAYLOAD_TYPE  104
 #define MP4V_PAYLOAD_TYPE  105
 
-static int tester_init(void) {
+MSWebCam* mediastreamer2_tester_get_mire_webcam(MSWebCamManager *mgr) {
 	MSWebCam *cam;
+
+	cam = ms_web_cam_manager_get_cam(mgr, "Mire: Mire (synthetic moving picture)");
+
+	if (cam == NULL) {
+		MSWebCamDesc *desc = ms_mire_webcam_desc_get();
+		if (desc){
+			cam=ms_web_cam_new(desc);
+			ms_web_cam_manager_add_cam(mgr,cam);
+		}
+	}
+
+	return cam;
+}
+
+static int tester_init(void) {
 	ms_init();
 	ms_filter_enable_statistics(TRUE);
 	ortp_init();
 	rtp_profile_set_payload(&rtp_profile, VP8_PAYLOAD_TYPE, &payload_type_vp8);
 	rtp_profile_set_payload(&rtp_profile, H264_PAYLOAD_TYPE, &payload_type_h264);
 	rtp_profile_set_payload(&rtp_profile, MP4V_PAYLOAD_TYPE, &payload_type_mp4v);
-	cam=ms_web_cam_new(&mire_desc);
-	ms_web_cam_manager_add_cam(ms_web_cam_manager_get(),cam);
 	return 0;
 }
 
@@ -64,14 +72,6 @@ static int tester_cleanup(void) {
 }
 
 #ifdef VIDEO_ENABLED
-/*#define MARIELLE_RTP_PORT 2564
-#define MARIELLE_RTCP_PORT 2565
-#define MARIELLE_IP "127.0.0.1"
-
-#define MARGAUX_RTP_PORT 9864
-#define MARGAUX_RTCP_PORT 9865
-#define MARGAUX_IP "127.0.0.1"
-*/
 
 typedef struct _video_stream_tester_stats_t {
 	OrtpEvQueue *q;
@@ -270,8 +270,6 @@ static void uninit_video_streams(video_stream_tester_t *vst1, video_stream_teste
 	vst2_pt = rtp_profile_get_payload(&rtp_profile, vst2->payload_type);
 	CU_ASSERT_PTR_NOT_NULL_FATAL(vst2_pt);
 
-	rtp_session_compute_send_bandwidth(vst1->vs->ms.sessions.rtp_session);
-	rtp_session_compute_send_bandwidth(vst2->vs->ms.sessions.rtp_session);
 	rtcp_send_bandwidth = rtp_session_get_rtcp_send_bandwidth(vst1->vs->ms.sessions.rtp_session);
 	ms_message("vst1: rtcp_send_bandwidth=%f, payload_type_bitrate=%d, rtcp_target_bandwidth=%f",
 		rtcp_send_bandwidth, payload_type_get_bitrate(vst1_pt), 0.06 * payload_type_get_bitrate(vst1_pt));
@@ -430,19 +428,19 @@ static void avpf_rpsi_count(void) {
 	int dummy=0;
 	int delay = 11000;
 	marielle->vconf=ms_new0(MSVideoConfiguration,1);
-	marielle->vconf->bitrate_limit=256000;
+	marielle->vconf->bitrate_limit=marielle->vconf->required_bitrate=256000;
 	marielle->vconf->fps=15;
 	marielle->vconf->vsize.height=MS_VIDEO_SIZE_CIF_H;
 	marielle->vconf->vsize.width=MS_VIDEO_SIZE_CIF_W;
-	marielle->cam = ms_web_cam_manager_get_cam(ms_web_cam_manager_get(), "Mire: Mire (synthetic moving picture)");
+	marielle->cam = mediastreamer2_tester_get_mire_webcam(ms_web_cam_manager_get());
 
 
 	margaux->vconf=ms_new0(MSVideoConfiguration,1);
-	margaux->vconf->bitrate_limit=256000;
+	margaux->vconf->bitrate_limit=margaux->vconf->required_bitrate=256000;
 	margaux->vconf->fps=5; /*to save cpu resource*/
 	margaux->vconf->vsize.height=MS_VIDEO_SIZE_CIF_H;
 	margaux->vconf->vsize.width=MS_VIDEO_SIZE_CIF_W;
-	margaux->cam = ms_web_cam_manager_get_cam(ms_web_cam_manager_get(), "Mire: Mire (synthetic moving picture)");
+	margaux->cam = mediastreamer2_tester_get_mire_webcam(ms_web_cam_manager_get());
 
 	if (supported) {
 		init_video_streams(marielle, margaux, TRUE, FALSE, &params,VP8_PAYLOAD_TYPE);
